<?php

namespace Drupal\single_image_formatter\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\EntityReferenceFieldItemListInterface;
use Drupal\media\Plugin\Field\FieldFormatter\MediaThumbnailFormatter;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'single_media_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "single_media_formatter",
 *   label = @Translation("Single media thumbnail"),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
if (\Drupal::moduleHandler()->moduleExists('media')) {
  class SingleMediaFormatter extends MediaThumbnailFormatter {

    /**
     * {@inheritdoc}
     */
    protected function getEntitiesToView(EntityReferenceFieldItemListInterface $items, $langcode) {
      $files = parent::getEntitiesToView($items, $langcode);
      $file = reset($files);
      return $file ? [$file] : [];
    }

  }
}

/**
 * If Media module is not installed, just return empty placeholder.
 */
else {
  class SingleMediaFormatter extends FormatterBase {

    /**
     * {@inheritdoc}
     */
    public function viewElements(FieldItemListInterface $items, $langcode) {
      return [];
    }

    /**
     * {@inheritdoc}
     */
    public static function isApplicable(FieldDefinitionInterface $field_definition) {
      return FALSE;
    }
  }
}

